@@ -24,6 +24,9 @@ from pathlib import Path
 from sqlalchemy import create_engine
 
 
+DB_FILE = "data-v3.db"
+
+
 def get_engine(connection_string):
     return create_engine(connection_string)
 
@@ -31,8 +34,9 @@ def get_engine(connection_string):
 def get_sqlite_connection_string(sqk_dir, network):
     data_dir = Path(sqk_dir).joinpath("data").joinpath(network)
     data_dir.mkdir(parents=True, exist_ok=True)
-    return "sqlite:////{}/data-v2.db".format(
+    return "sqlite:////{}/{}".format(
         data_dir,
+        DB_FILE,
     )
 
 
