@@ -35,8 +35,8 @@ from sqlalchemy import or_
 from sqlalchemy.sql import select
 from sqlalchemy.sql import tuple_
 from squeak.core import CSqueak
-from squeak.core.signing import SqueakPrivateKey
-from squeak.core.signing import SqueakPublicKey
+from squeak.core.keys import SqueakPrivateKey
+from squeak.core.keys import SqueakPublicKey
 
 from squeaknode.core.lightning_address import LightningAddressHostPort
 from squeaknode.core.peer_address import Network
@@ -84,6 +84,10 @@ class SqueakDb:
         logger.debug("SqlAlchemy version: {}".format(sqlalchemy.__version__))
         run_migrations(self.engine)
 
+        # Create aliases for profiles
+        self.author_profiles = self.profiles.alias()
+        self.recipient_profiles = self.profiles.alias()
+
     def init_with_retries(
             self,
             num_retries=INIT_NUM_RETRIES,
@@ -153,13 +157,11 @@ class SqueakDb:
         return self.timestamp_now_ms > \
             self.squeaks.c.created_time_ms + interval_s * 1000
 
-    @property
-    def profile_has_private_key(self):
-        return self.profiles.c.private_key != None  # noqa: E711
+    def profile_has_private_key(self, profiles_table):
+        return profiles_table.c.private_key != None  # noqa: E711
 
-    @property
-    def profile_is_following(self):
-        return self.profiles.c.following == True  # noqa: E711
+    def profile_is_following(self, profiles_table):
+        return profiles_table.c.following == True  # noqa: E711
 
     @property
     def timestamp_now_ms(self):
@@ -214,11 +216,16 @@ class SqueakDb:
             created_time_ms=self.timestamp_now_ms,
             hash=get_hash(squeak),
             squeak=squeak.serialize(),
-            reply_hash=squeak.hashReplySqk if squeak.is_reply else None,
+            reply_hash=(squeak.hashReplySqk
+                        if squeak.is_reply
+                        else None),
             block_hash=squeak.hashBlock,
             block_height=squeak.nBlockHeight,
             time_s=squeak.nTime,
             author_public_key=squeak.GetPubKey().to_bytes(),
+            recipient_public_key=(squeak.GetRecipientPubKey().to_bytes()
+                                  if squeak.is_private_message
+                                  else None),
             secret_key=None,
             block_time_s=block_header.nTime,
         )
@@ -255,12 +262,20 @@ class SqueakDb:
 
     def get_squeak_entry(self, squeak_hash: bytes) -> Optional[SqueakEntry]:
         """ Get a squeak with the author profile. """
+        # author_profiles = self.profiles.alias()
+        # recipient_profiles = self.profiles.alias()
+
         s = (
-            select([self.squeaks, self.profiles])
+            select([self.squeaks, self.author_profiles, self.recipient_profiles])
             .select_from(
-                self.squeaks.outerjoin(
-                    self.profiles,
-                    self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                self.squeaks
+                .outerjoin(
+                    self.author_profiles,
+                    self.author_profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.recipient_profiles,
+                    self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
             )
             .where(self.squeaks.c.hash == squeak_hash)
@@ -270,7 +285,11 @@ class SqueakDb:
             row = result.fetchone()
             if row is None:
                 return None
-            return self._parse_squeak_entry(row)
+            return self._parse_squeak_entry(
+                row,
+                # author_profiles_table=author_profiles,
+                # recipient_profiles_table=recipient_profiles,
+            )
 
     def get_timeline_squeak_entries(
             self,
@@ -293,14 +312,24 @@ class SqueakDb:
             last_squeak_hash.hex(),
         ))
         s = (
-            select([self.squeaks, self.profiles])
+            # select([self.squeaks, self.profiles])
+            select([self.squeaks, self.author_profiles, self.recipient_profiles])
             .select_from(
-                self.squeaks.outerjoin(
-                    self.profiles,
-                    self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # self.squeaks.outerjoin(
+                #     self.profiles,
+                #     self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # )
+                self.squeaks
+                .outerjoin(
+                    self.author_profiles,
+                    self.author_profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.recipient_profiles,
+                    self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
             )
-            .where(self.profile_is_following)
+            .where(self.profile_is_following(self.author_profiles))
             .where(
                 tuple_(
                     self.squeaks.c.block_height,
@@ -342,11 +371,21 @@ class SqueakDb:
             last_squeak_hash.hex(),
         ))
         s = (
-            select([self.squeaks, self.profiles])
+            # select([self.squeaks, self.profiles])
+            select([self.squeaks, self.author_profiles, self.recipient_profiles])
             .select_from(
-                self.squeaks.outerjoin(
-                    self.profiles,
-                    self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # self.squeaks.outerjoin(
+                #     self.profiles,
+                #     self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # )
+                self.squeaks
+                .outerjoin(
+                    self.author_profiles,
+                    self.author_profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.recipient_profiles,
+                    self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
             )
             .where(
@@ -396,11 +435,21 @@ class SqueakDb:
             last_squeak_hash.hex(),
         ))
         s = (
-            select([self.squeaks, self.profiles])
+            # select([self.squeaks, self.profiles])
+            select([self.squeaks, self.author_profiles, self.recipient_profiles])
             .select_from(
-                self.squeaks.outerjoin(
-                    self.profiles,
-                    self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # self.squeaks.outerjoin(
+                #     self.profiles,
+                #     self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # )
+                self.squeaks
+                .outerjoin(
+                    self.author_profiles,
+                    self.author_profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.recipient_profiles,
+                    self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
             )
             .where(self.squeaks.c.author_public_key == public_key.to_bytes())
@@ -451,11 +500,21 @@ class SqueakDb:
             last_squeak_hash.hex(),
         ))
         s = (
-            select([self.squeaks, self.profiles])
+            # select([self.squeaks, self.profiles])
+            select([self.squeaks, self.author_profiles, self.recipient_profiles])
             .select_from(
-                self.squeaks.outerjoin(
-                    self.profiles,
-                    self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # self.squeaks.outerjoin(
+                #     self.profiles,
+                #     self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # )
+                self.squeaks
+                .outerjoin(
+                    self.author_profiles,
+                    self.author_profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.recipient_profiles,
+                    self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
             )
             .where(self.squeaks.c.content.ilike(f'%{search_text}%'))
@@ -508,14 +567,23 @@ class SqueakDb:
         )
 
         s = (
-            select([self.squeaks, self.profiles])
+            # select([self.squeaks, self.profiles])
+            select([self.squeaks, self.author_profiles, self.recipient_profiles])
             .select_from(
                 self.squeaks.join(
                     ancestors,
                     ancestors.c.hash == self.squeaks.c.hash,
-                ).outerjoin(
-                    self.profiles,
-                    self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                    # ).outerjoin(
+                    #     self.profiles,
+                    #     self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.author_profiles,
+                    self.author_profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.recipient_profiles,
+                    self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
             )
             .order_by(
@@ -570,11 +638,21 @@ class SqueakDb:
             last_squeak_hash.hex(),
         ))
         s = (
-            select([self.squeaks, self.profiles])
+            # select([self.squeaks, self.profiles])
+            select([self.squeaks, self.author_profiles, self.recipient_profiles])
             .select_from(
-                self.squeaks.outerjoin(
-                    self.profiles,
-                    self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # self.squeaks.outerjoin(
+                #     self.profiles,
+                #     self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # )
+                self.squeaks
+                .outerjoin(
+                    self.author_profiles,
+                    self.author_profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.recipient_profiles,
+                    self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
             )
             .where(self.squeaks.c.reply_hash == squeak_hash)
@@ -666,21 +744,19 @@ class SqueakDb:
             num_squeaks = row["num_squeaks"]
             return num_squeaks
 
-    def number_of_squeaks_with_public_key_in_block_range(
+    def number_of_squeaks_with_public_key_with_block_height(
         self,
         public_key: SqueakPublicKey,
-        min_block: int,
-        max_block: int,
+        block_height: int,
     ) -> int:
-        """ Get number of squeaks with address in block range. """
+        """ Get number of squeaks with public key with block height. """
         s = (
             select([
                 func.count().label("num_squeaks"),
             ])
             .select_from(self.squeaks)
             .where(self.squeaks.c.author_public_key == public_key.to_bytes())
-            .where(self.squeaks.c.block_height >= min_block)
-            .where(self.squeaks.c.block_height <= max_block)
+            .where(self.squeaks.c.block_height == block_height)
         )
         with self.get_connection() as connection:
             result = connection.execute(s)
@@ -696,15 +772,25 @@ class SqueakDb:
         criteria for deletion.
         """
         s = (
-            select([self.squeaks, self.profiles])
+            # select([self.squeaks, self.profiles])
+            select([self.squeaks, self.author_profiles, self.recipient_profiles])
             .select_from(
-                self.squeaks.outerjoin(
-                    self.profiles,
-                    self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # self.squeaks.outerjoin(
+                #     self.profiles,
+                #     self.profiles.c.public_key == self.squeaks.c.author_public_key,
+                # )
+                self.squeaks
+                .outerjoin(
+                    self.author_profiles,
+                    self.author_profiles.c.public_key == self.squeaks.c.author_public_key,
+                )
+                .outerjoin(
+                    self.recipient_profiles,
+                    self.recipient_profiles.c.public_key == self.squeaks.c.recipient_public_key,
                 )
             )
             .where(self.squeak_is_older_than_retention(interval_s))
-            .where(not_(self.profile_has_private_key))
+            .where(not_(self.profile_has_private_key(self.author_profiles)))
             .where(not_(self.squeak_is_liked))
         )
         with self.get_connection() as connection:
@@ -739,7 +825,10 @@ class SqueakDb:
 
     def get_signing_profiles(self) -> List[SqueakProfile]:
         """ Get all signing profiles. """
-        s = select([self.profiles]).where(self.profile_has_private_key)
+        s = (
+            select([self.profiles])
+            .where(self.profile_has_private_key(self.profiles))
+        )
         with self.get_connection() as connection:
             result = connection.execute(s)
             rows = result.fetchall()
@@ -748,7 +837,10 @@ class SqueakDb:
 
     def get_contact_profiles(self) -> List[SqueakProfile]:
         """ Get all contact profiles. """
-        s = select([self.profiles]).where(not_(self.profile_has_private_key))
+        s = (
+            select([self.profiles])
+            .where(not_(self.profile_has_private_key(self.profiles)))
+        )
         with self.get_connection() as connection:
             result = connection.execute(s)
             rows = result.fetchall()
@@ -824,7 +916,7 @@ class SqueakDb:
         with self.get_connection() as connection:
             connection.execute(delete_profile_stmt)
 
-    def set_profile_image(self, profile_id: int, profile_image: bytes) -> None:
+    def set_profile_image(self, profile_id: int, profile_image: Optional[bytes]) -> None:
         """ Set a profile image. """
         stmt = (
             self.profiles.update()
@@ -834,15 +926,22 @@ class SqueakDb:
         with self.get_connection() as connection:
             connection.execute(stmt)
 
-    def set_squeak_decryption_key(self, squeak_hash: bytes, secret_key: bytes, content: str) -> None:
-        """ Set the decryption key and decrypted content of a squeak. """
+    def set_squeak_secret_key(self, squeak_hash: bytes, secret_key: bytes) -> None:
+        """ Set the secret key of a squeak. """
         stmt = (
             self.squeaks.update()
             .where(self.squeaks.c.hash == squeak_hash)
-            .values(
-                secret_key=secret_key,
-                content=content,
-            )
+            .values(secret_key=secret_key)
+        )
+        with self.get_connection() as connection:
+            connection.execute(stmt)
+
+    def set_squeak_decrypted_content(self, squeak_hash: bytes, content: str) -> None:
+        """ Set the decrypted content of a squeak. """
+        stmt = (
+            self.squeaks.update()
+            .where(self.squeaks.c.hash == squeak_hash)
+            .values(content=content)
         )
         with self.get_connection() as connection:
             connection.execute(stmt)
@@ -1055,7 +1154,7 @@ class SqueakDb:
         with self.get_connection() as connection:
             connection.execute(stmt)
 
-    def insert_sent_payment(self, sent_payment: SentPayment):
+    def insert_sent_payment(self, sent_payment: SentPayment) -> int:
         """ Insert a new sent payment. """
         ins = self.sent_payments.insert().values(
             created_time_ms=self.timestamp_now_ms,
@@ -1357,7 +1456,6 @@ class SqueakDb:
         """
         ins = self.configs.insert().values(
             username=user_config.username,
-            twitter_bearer_token=user_config.twitter_bearer_token,
         )
         with self.get_connection() as connection:
             try:
@@ -1378,16 +1476,6 @@ class SqueakDb:
                 return None
             return self._parse_user_config(row)
 
-    def set_config_twitter_bearer_token(self, username: str, twitter_bearer_token: str) -> None:
-        """ Set a config twitter bearer token. """
-        stmt = (
-            self.configs.update()
-            .where(self.configs.c.username == username)
-            .values(twitter_bearer_token=twitter_bearer_token)
-        )
-        with self.get_connection() as connection:
-            connection.execute(stmt)
-
     def set_config_sell_price_msat(self, username: str, sell_price_msat: int) -> None:
         """ Set a config sell price msat. """
         stmt = (
@@ -1417,6 +1505,7 @@ class SqueakDb:
         ins = self.twitter_accounts.insert().values(
             handle=twitter_account.handle,
             profile_id=twitter_account.profile_id,
+            bearer_token=twitter_account.bearer_token,
         )
         with self.get_connection() as connection:
             try:
@@ -1457,17 +1546,25 @@ class SqueakDb:
     def _parse_squeak(self, row) -> CSqueak:
         return CSqueak.deserialize(row["squeak"])
 
+    # def _parse_squeak_entry(self, row, author_profiles_table=None, recipient_profiles_table=None) -> SqueakEntry:
     def _parse_squeak_entry(self, row) -> SqueakEntry:
+        public_key_bytes = row["author_public_key"]
+        recipient_public_key_bytes = row["recipient_public_key"]
         secret_key_column = row["secret_key"]
         is_locked = bool(secret_key_column)
         reply_to = (
             row["reply_hash"]) if row["reply_hash"] else None
         liked_time_ms = row["liked_time_ms"]
-        profile = self._try_parse_squeak_profile(row)
+        profile = self._try_parse_squeak_profile(
+            row, profiles_table=self.author_profiles)
+        recipient_profile = self._try_parse_squeak_profile(
+            row, profiles_table=self.recipient_profiles)
         return SqueakEntry(
             squeak_hash=(row["hash"]),
             serialized_squeak=(row["squeak"]),
-            public_key=SqueakPublicKey.from_bytes(row["author_public_key"]),
+            public_key=SqueakPublicKey.from_bytes(public_key_bytes),
+            recipient_public_key=SqueakPublicKey.from_bytes(
+                recipient_public_key_bytes) if recipient_public_key_bytes else None,
             block_height=row["block_height"],
             block_hash=(row["block_hash"]),
             block_time=row["block_time_s"],
@@ -1478,25 +1575,33 @@ class SqueakDb:
             liked_time_ms=liked_time_ms,
             content=row["content"],
             squeak_profile=profile,
+            recipient_squeak_profile=recipient_profile,
         )
 
-    def _parse_squeak_profile(self, row) -> SqueakProfile:
-        private_key_bytes = row["private_key"]
+    def _parse_squeak_profile(self, row, profiles_table=None) -> SqueakProfile:
+        profiles_table = profiles_table if (
+            profiles_table is not None) else self.profiles
+
+        private_key_bytes = row[profiles_table.c.private_key]
         private_key = SqueakPrivateKey.from_bytes(
             private_key_bytes) if private_key_bytes else None
         return SqueakProfile(
-            profile_id=row["profile_id"],
-            profile_name=row["profile_name"],
+            profile_id=row[profiles_table.c.profile_id],
+            profile_name=row[profiles_table.c.profile_name],
             private_key=private_key,
-            public_key=SqueakPublicKey.from_bytes(row["public_key"]),
-            following=row["following"],
-            profile_image=row["profile_image"],
+            public_key=SqueakPublicKey.from_bytes(
+                row[profiles_table.c.public_key]),
+            following=row[profiles_table.c.following],
+            profile_image=row[profiles_table.c.profile_image],
         )
 
-    def _try_parse_squeak_profile(self, row) -> Optional[SqueakProfile]:
-        if row["profile_id"] is None:
+    def _try_parse_squeak_profile(self, row, profiles_table=None) -> Optional[SqueakProfile]:
+        profiles_table = profiles_table if (
+            profiles_table is not None) else self.profiles
+
+        if row[profiles_table.c.profile_id] is None:
             return None
-        return self._parse_squeak_profile(row)
+        return self._parse_squeak_profile(row, profiles_table=profiles_table)
 
     def _parse_squeak_peer(self, row) -> SqueakPeer:
         return SqueakPeer(
@@ -1600,7 +1705,6 @@ class SqueakDb:
     def _parse_user_config(self, row) -> UserConfig:
         return UserConfig(
             username=row["username"],
-            twitter_bearer_token=row["twitter_bearer_token"],
             sell_price_msat=row["sell_price_msat"],
         )
 
@@ -1610,5 +1714,6 @@ class SqueakDb:
             twitter_account_id=row["twitter_account_id"],
             handle=row["handle"],
             profile_id=row["profile_id"],
+            bearer_token=row["bearer_token"],
             profile=profile,
         )
